@@ -11,7 +11,6 @@ import serial.tools.list_ports
 
 import glob
 import subprocess as sp
-from v4lc import V4L2_CTL, get_resolutions
 
 import sys
 
@@ -23,6 +22,9 @@ import time
 from contextlib import contextmanager
 import signal
 
+from v4lc import V4L2_CTL, get_resolutions
+
+
 # print("v... unit 'unitname' loaded, version:",__version__)
 
 @contextmanager
@@ -156,29 +158,34 @@ def show_cam(vidnum, res, recommended=""):
         timeoutok = False
         ret = False
         frame = None
-        try: #----this catches errors of libjpeg with cv2.CAP_V4L2
-#            with timeout(3): #--- this may help when no CAP_V4L2; MAYNOT
-            print("D... reading frame" )
-            ret, frame = cap.read()
-            #wname = f"res {frame.shape[1]}x{frame.shape[0]}"
-            nfrm+=1
-            print("D... got frame",nfrm, "ret=", ret)
-#        except TimeoutError:
-#            timeoutok = True
-#            nfrm = 0
-        except Exception as ex:
-            print("D... SOME OTHER EXCEPTION ON RECV...", ex)
+        if (cap is None) or (not cap.isOpened()):
+            print("X... camera None or not Opened)")
+            ret = False
+        else:
+            try: #----this catches errors of libjpeg with cv2.CAP_V4L2
+    #            with timeout(3): #--- this may help when no CAP_V4L2; MAYNOT
+                print("D... reading frame" )
+                ret, frame = cap.read()
+                #wname = f"res {frame.shape[1]}x{frame.shape[0]}"
+                nfrm+=1
+                print("D... got frame",nfrm, "ret=", ret)
+    #        except TimeoutError:
+    #            timeoutok = True
+    #            nfrm = 0
+            except Exception as ex:
+                print("D... SOME OTHER EXCEPTION ON RECV...", ex)
 
 #        if  timeoutok:
 #            print("X... timout")
 
         if not ret:
-            time.sleep(2)
+            time.sleep(0.5)
             vids = recommend_video(recommended) # try to re-init the same video
             if len(vids)>0:
                 vidnum = vids[0]
                 cap = init_cam( vidnum, res)
                 nfrm = 0
+
             if  (not frame_prev is None):
 
                 # create gray + moving lines
@@ -268,6 +275,7 @@ def recommend_video( prefname="" ):
     recomvid = []
     for vid in sorted(vids):
         CMD = f"udevadm info --name={vid}"
+        # print(f"D... cmd={CMD}")
         res = ""
         ok=False
         try:
@@ -275,6 +283,7 @@ def recommend_video( prefname="" ):
             ok=True
         except:
             print("X... ... ERROR "+CMD)
+
         if ok:
             #print(res)
             try: # I saw there was no result...when reconnecting camera....
@@ -288,34 +297,33 @@ def recommend_video( prefname="" ):
                 id_path = id_path.split("=")[1]
                 id_path = ":".join( id_path.split(":")[2:] )
             except  Exception as ex:
-                print("X... udevadm error...", ex)
+                print("X... udevadm error...", ex, vid)
                 ok = False
-            if not ok:
-                return []
 
-            cc = V4L2_CTL( vid )
-            capa = cc.get_capbilities()
-            GE = ""
-            if "gain" in capa:
-                GE = "g"
-            if "exposure_absolute" in capa:
-                GE+= "e"
-            # print(   )
+            if ok:
+                cc = V4L2_CTL( vid )
+                capa = cc.get_capbilities()
+                GE = ""
+                if "gain" in capa:
+                    GE = "g"
+                if "exposure_absolute" in capa:
+                    GE+= "e"
+                # print(   )
 
-            if len(capa) > 0:
-                bus,dev,name = lsusbv(f"{vendor}:{model}")
-                #print(usb_hubs)
-                vidid = int(vid[vid.find('/dev/video')+10:])
-                pref = " "
-                if prefname == "":
-                    recomvid.append( vidid )
-                else:
-                    if (name.find(prefname)>=0) or (id_path.find(prefname)>=0):
-                        recomvid.append( vidid)
-                        pref = "*"
-                    #if self.verbose:print("     ",vendor, model, vname)
-                print(f"{vidid:2d}   {bus:4s} {dev:4s} {usb_hubs[bus]:6s} {vendor:4s}:{model:4s}  {name:20s}  {id_path:16s}  {len(capa)}{GE}   {pref}" )
-                # verify_resolutions( vidid, resolutions )
+                if len(capa) > 0:
+                    bus,dev,name = lsusbv(f"{vendor}:{model}")
+                    #print(usb_hubs)
+                    vidid = int(vid[vid.find('/dev/video')+10:])
+                    pref = " "
+                    if str(prefname) == "":
+                        recomvid.append( vidid )
+                    else:
+                        if (name.find(str(prefname))>=0) or (id_path.find(str(prefname))>=0):
+                            recomvid.append( vidid)
+                            pref = "*"
+                        #if self.verbose:print("     ",vendor, model, vname)
+                    print(f"{vidid:2d}   {bus:4s} {dev:4s} {usb_hubs[bus]:6s} {vendor:4s}:{model:4s}  {name:20s}  {id_path:16s}  {len(capa)}{GE}   {pref}" )
+                    # verify_resolutions( vidid, resolutions )
 
     print("_"*80)
     print(recomvid)
